@@ -24,7 +24,8 @@ class Config
         bool bDownload;
         bool bList;
         bool bListDetails;
-        bool bLogin;
+        bool bLoginHTTP;
+        bool bLoginAPI;
         bool bRepair;
         bool bInstallers;
         bool bExtras;
@@ -53,6 +54,7 @@ class Config
         std::string sToken;
         std::string sSecret;
         std::string sVersionString;
+        std::string sVersionNumber;
         std::string sConfigDirectory;
         std::string sCookiePath;
         std::string sConfigFilePath;
@@ -67,14 +69,16 @@ class Config
         std::string sDLCSubdir;
         std::string sGameSubdir;
         std::string sFileIdString;
+        std::string sOutputFilename;
         std::string sLanguagePriority;
         std::string sPlatformPriority;
         std::string sIgnoreDLCCountRegex;
         std::vector<unsigned int> vLanguagePriority;
         std::vector<unsigned int> vPlatformPriority;
 
-        unsigned int iInstallerType;
+        unsigned int iInstallerPlatform;
         unsigned int iInstallerLanguage;
+        unsigned int iInclude;
         int iRetries;
         int iWait;
         int iCacheValid;
