@@ -5,7 +5,7 @@
 
 #include <iostream>
 #include <vector>
-#include <jsoncpp/json/json.h>
+#include <json/json.h>
 
 class gameFile
 {
@@ -19,6 +19,7 @@ class gameFile
         std::string size;
         unsigned int platform;
         unsigned int language;
+        int score;
         int silent;
         void setFilepath(const std::string& path);
         std::string getFilepath();
