@@ -17,11 +17,12 @@
 #include <sstream>
 #include <rhash.h>
 #include <boost/filesystem.hpp>
+#include <boost/regex.hpp>
 #include <json/json.h>
 
 struct gameSpecificConfig
 {
-    unsigned int iInstallerType;
+    unsigned int iInstallerPlatform;
     unsigned int iInstallerLanguage;
     bool bDLC;
     bool bIgnoreDLCCount;
@@ -41,6 +42,12 @@ namespace Util
     int getTerminalWidth();
     void getDownloaderUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls);
     std::vector<std::string> getDLCNamesFromJSON(const Json::Value &root);
+    std::string getHomeDir();
+    std::string getConfigHome();
+    std::string getCacheHome();
+    std::vector<std::string> tokenize(const std::string& str, const std::string& separator = ",");
+    unsigned int getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options);
+    std::string getOptionNameString(const unsigned int& value, const std::vector<GlobalConstants::optionsStruct>& options);
 }
 
 #endif // UTIL_H
