@@ -13,7 +13,7 @@
 #include <boost/filesystem.hpp>
 #include <boost/program_options.hpp>
 
-#define VERSION_NUMBER "2.24"
+#define VERSION_NUMBER "2.26"
 
 #ifndef VERSION_STRING
 #   define VERSION_STRING "LGOGDownloader " VERSION_NUMBER
@@ -26,86 +26,101 @@ template<typename T> void set_vm_value(std::map<std::string, bpo::variable_value
     vm[option].value() = boost::any(value);
 }
 
-// Parse the priority string, making it an array of numeric codes, and override the ORed type if required
-void handle_priority(const std::string &what, const std::string &priority_string, std::vector<unsigned int> &priority, unsigned int &type)
+// Parse the options string
+void parseOptionString(const std::string &option_string, std::vector<unsigned int> &priority, unsigned int &type, const std::vector<GlobalConstants::optionsStruct>& options)
 {
-    size_t idx = 0, found;
-
-    while ((found = priority_string.find(',', idx)) != std::string::npos)
-	{
-	    priority.push_back(std::stoi(priority_string.substr(idx, found - idx)));
-	    idx = found + 1;
-	}
-    priority.push_back(std::stoi(priority_string.substr(idx)));
-
-    unsigned int wanted = 0;
-    #ifdef DEBUG
-        std::cerr << "DEBUG INFO (handle_priority): for " << what << " found ";
-    #endif
-    for (std::vector<unsigned int>::iterator it = priority.begin(); it != priority.end(); it++)
-	{
-	    wanted += *it;
-            #ifdef DEBUG
-  	      std::cerr << *it << " ";
-            #endif
-	}
-    #ifdef DEBUG
-        std::cerr << std::endl;
-    #endif
-
-    if (wanted != type)
-	{
-            type = wanted;
-	    std::cout << "Warning: for " << what << " the priority string doesn't match the enabled installers, forcing enabled installers to " << type << std::endl;
-	}
+    type = 0;
+    std::vector<std::string> tokens_priority = Util::tokenize(option_string, ",");
+    for (std::vector<std::string>::iterator it_priority = tokens_priority.begin(); it_priority != tokens_priority.end(); it_priority++)
+    {
+        unsigned int value = 0;
+        std::vector<std::string> tokens_value = Util::tokenize(*it_priority, "+");
+        for (std::vector<std::string>::iterator it_value = tokens_value.begin(); it_value != tokens_value.end(); it_value++)
+        {
+            value |= Util::getOptionValue(*it_value, options);
+        }
+        priority.push_back(value);
+        type |= value;
+    }
 }
 
 int main(int argc, char *argv[])
 {
+    // Constants for option selection with include/exclude
+    /* TODO: Add options to give better control for user
+             For example: option to select base game and DLC installers separately,
+             this requires some changes to Downloader class to implement */
+    const unsigned int OPTION_INSTALLERS = 1 << 0;
+    const unsigned int OPTION_EXTRAS     = 1 << 1;
+    const unsigned int OPTION_PATCHES    = 1 << 2;
+    const unsigned int OPTION_LANGPACKS  = 1 << 3;
+    const unsigned int OPTION_COVERS     = 1 << 4;
+    const unsigned int OPTION_DLCS       = 1 << 5;
+
+    const std::vector<GlobalConstants::optionsStruct> INCLUDE_OPTIONS =
+    {
+        { OPTION_INSTALLERS, "i", "Installers",     "i|installers"              },
+        { OPTION_EXTRAS,     "e", "Extras",         "e|extras"                  },
+        { OPTION_PATCHES,    "p", "Patches",        "p|patches"                 },
+        { OPTION_LANGPACKS,  "l", "Language packs", "l|languagepacks|langpacks" },
+        { OPTION_COVERS,     "c", "Covers",         "c|cover|covers"            },
+        { OPTION_DLCS,       "d", "DLCs",           "d|dlc|dlcs"                }
+    };
+
     Config config;
     config.sVersionString = VERSION_STRING;
-    char *xdgconfig = getenv("XDG_CONFIG_HOME");
-    char *xdgcache = getenv("XDG_CACHE_HOME");
-    std::string home = (std::string)getenv("HOME");
-
-    if (xdgcache)
-        config.sCacheDirectory = (std::string)xdgcache + "/lgogdownloader";
-    else
-        config.sCacheDirectory = home + "/.cache/lgogdownloader";
+    config.sVersionNumber = VERSION_NUMBER;
 
+    config.sCacheDirectory = Util::getCacheHome() + "/lgogdownloader";
     config.sXMLDirectory = config.sCacheDirectory + "/xml";
 
+    config.sConfigDirectory = Util::getConfigHome() + "/lgogdownloader";
+    config.sCookiePath = config.sConfigDirectory + "/cookies.txt";
+    config.sConfigFilePath = config.sConfigDirectory + "/config.cfg";
+    config.sBlacklistFilePath = config.sConfigDirectory + "/blacklist.txt";
+
+    std::string priority_help_text = "Set priority by separating values with \",\"\nCombine values by separating with \"+\"";
     // Create help text for --platform option
     std::string platform_text = "Select which installers are downloaded\n";
-    unsigned int platform_sum = 0;
+    unsigned int platform_all = Util::getOptionValue("all", GlobalConstants::PLATFORMS);
     for (unsigned int i = 0; i < GlobalConstants::PLATFORMS.size(); ++i)
     {
-        platform_text += std::to_string(GlobalConstants::PLATFORMS[i].platformId) + " = " + GlobalConstants::PLATFORMS[i].platformString + "\n";
-        platform_sum += GlobalConstants::LANGUAGES[i].languageId;
+        platform_text += GlobalConstants::PLATFORMS[i].str + " = " + GlobalConstants::PLATFORMS[i].regexp + "|" + std::to_string(GlobalConstants::PLATFORMS[i].id) + "\n";
     }
-    platform_text += std::to_string(platform_sum) + " = All";
+    platform_text += "All = all|" + std::to_string(platform_all);
+    platform_text += "\n\n" + priority_help_text;
+    platform_text += "\nExample: Linux if available otherwise Windows and Mac: l,w+m";
 
     // Create help text for --language option
     std::string language_text = "Select which language installers are downloaded\n";
-    unsigned int language_sum = 0;
+    unsigned int language_all = Util::getOptionValue("all", GlobalConstants::LANGUAGES);
     for (unsigned int i = 0; i < GlobalConstants::LANGUAGES.size(); ++i)
     {
-        language_text += std::to_string(GlobalConstants::LANGUAGES[i].languageId) + " = " + GlobalConstants::LANGUAGES[i].languageString + "\n";
-        language_sum += GlobalConstants::LANGUAGES[i].languageId;
+        language_text +=  GlobalConstants::LANGUAGES[i].str + " = " + GlobalConstants::LANGUAGES[i].regexp + "|" + std::to_string(GlobalConstants::LANGUAGES[i].id) + "\n";
     }
-    language_text += "Add the values to download multiple languages\nAll = " + std::to_string(language_sum) + "\n"
-                    + "French + Polish = " + std::to_string(GlobalConstants::LANGUAGE_FR) + "+" + std::to_string(GlobalConstants::LANGUAGE_PL) + " = " + std::to_string(GlobalConstants::LANGUAGE_FR | GlobalConstants::LANGUAGE_PL);
+    language_text += "Add the values to download multiple languages\nAll = all|" + std::to_string(language_all) + "\n"
+                    + "French + Polish = \"fr+pl\"|" + std::to_string(GlobalConstants::LANGUAGE_FR | GlobalConstants::LANGUAGE_PL) + " (" + std::to_string(GlobalConstants::LANGUAGE_FR) + "+" + std::to_string(GlobalConstants::LANGUAGE_PL) + "=" + std::to_string(GlobalConstants::LANGUAGE_FR | GlobalConstants::LANGUAGE_PL) + ")";
+    language_text += "\n\n" + priority_help_text;
+    language_text += "\nExample: German if available otherwise English and French: de,en+fr";
 
     // Create help text for --check-orphans
-    std::string orphans_regex_default = ".*\\.(zip|exe|bin|dmg|old|deb|tar\\.gz|pkg)$"; // Limit to files with these extensions (".old" is for renamed older version files)
+    std::string orphans_regex_default = ".*\\.(zip|exe|bin|dmg|old|deb|tar\\.gz|pkg|sh)$"; // Limit to files with these extensions (".old" is for renamed older version files)
     std::string check_orphans_text = "Check for orphaned files (files found on local filesystem that are not found on GOG servers). Sets regular expression filter (Perl syntax) for files to check. If no argument is given then the regex defaults to '" + orphans_regex_default + "'";
 
     // Help text for subdir options
     std::string subdir_help_text = "\nTemplates:\n- %platform%\n- %gamename%\n- %dlcname%";
-    // Help text for priority options
-    std::string priority_help_text = "\nIf set, only the first matching one will be downloaded. If unset, all matching combinations will be downloaded.\nSyntax: use a string separated by \",\"";
 
+    // Help text for include and exclude options
+    std::string include_options_text;
+    for (unsigned int i = 0; i < INCLUDE_OPTIONS.size(); ++i)
+    {
+        include_options_text +=  INCLUDE_OPTIONS[i].str + " = " + INCLUDE_OPTIONS[i].regexp + "|" + std::to_string(INCLUDE_OPTIONS[i].id) + "\n";
+    }
+    include_options_text += "Separate with \",\" to use multiple values";
+
+    std::vector<std::string> vFileIdStrings;
     std::vector<std::string> unrecognized_options_cfg;
+    std::vector<std::string> unrecognized_options_cli;
     bpo::variables_map vm;
     bpo::options_description options_cli_all("Options");
     bpo::options_description options_cli_no_cfg;
@@ -118,40 +133,39 @@ int main(int argc, char *argv[])
         bool bNoColor = false;
         bool bNoUnicode = false;
         bool bNoDuplicateHandler = false;
-        bool bNoInstallers = false;
-        bool bNoExtras = false;
-        bool bNoPatches = false;
-        bool bNoLanguagePacks = false;
-        bool bNoDLC = false;
         bool bNoRemoteXML = false;
         bool bNoSubDirectories = false;
-        bool bNoDeb = false;
-        bool bNoTarGz = false;
-        bool bNoCover = false;
         bool bNoPlatformDetection = false;
+        bool bLogin = false;
+        std::string sInstallerPlatform;
+        std::string sInstallerLanguage;
+        std::string sIncludeOptions;
+        std::string sExcludeOptions;
         config.bReport = false;
         // Commandline options (no config file)
         options_cli_no_cfg.add_options()
             ("help,h", "Print help message")
             ("version", "Print version information")
-            ("login", bpo::value<bool>(&config.bLogin)->zero_tokens()->default_value(false), "Login")
+            ("login", bpo::value<bool>(&bLogin)->zero_tokens()->default_value(false), "Login")
             ("list", bpo::value<bool>(&config.bList)->zero_tokens()->default_value(false), "List games")
             ("list-details", bpo::value<bool>(&config.bListDetails)->zero_tokens()->default_value(false), "List games with detailed info")
             ("download", bpo::value<bool>(&config.bDownload)->zero_tokens()->default_value(false), "Download")
             ("repair", bpo::value<bool>(&config.bRepair)->zero_tokens()->default_value(false), "Repair downloaded files\nUse --repair --download to redownload files when filesizes don't match (possibly different version). Redownload will rename the old file (appends .old to filename)")
             ("game", bpo::value<std::string>(&config.sGameRegex)->default_value(""), "Set regular expression filter\nfor download/list/repair (Perl syntax)\nAliases: \"all\", \"free\"\nAlias \"free\" doesn't work with cached details")
-            ("create-xml", bpo::value<std::string>(&config.sXMLFile)->default_value(""), "Create GOG XML for file\n\"automatic\" to enable automatic XML creation")
+            ("create-xml", bpo::value<std::string>(&config.sXMLFile)->implicit_value("automatic"), "Create GOG XML for file\n\"automatic\" to enable automatic XML creation")
             ("update-check", bpo::value<bool>(&config.bUpdateCheck)->zero_tokens()->default_value(false), "Check for update notifications")
             ("check-orphans", bpo::value<std::string>(&config.sOrphanRegex)->implicit_value(""), check_orphans_text.c_str())
             ("status", bpo::value<bool>(&config.bCheckStatus)->zero_tokens()->default_value(false), "Show status of files\n\nOutput format:\nstatuscode gamename filename filesize filehash\n\nStatus codes:\nOK - File is OK\nND - File is not downloaded\nMD5 - MD5 mismatch, different version\nFS - File size mismatch, incomplete download")
             ("save-config", bpo::value<bool>(&config.bSaveConfig)->zero_tokens()->default_value(false), "Create config file with current settings")
             ("reset-config", bpo::value<bool>(&config.bResetConfig)->zero_tokens()->default_value(false), "Reset config settings to default")
             ("report", bpo::value<std::string>(&config.sReportFilePath)->implicit_value("lgogdownloader-report.log"), "Save report of downloaded/repaired files to specified file\nDefault filename: lgogdownloader-report.log")
-            ("no-cover", bpo::value<bool>(&bNoCover)->zero_tokens()->default_value(false), "Don't download cover images. Overrides --cover option.\nUseful for making exceptions when \"cover\" is set to true in config file.")
             ("update-cache", bpo::value<bool>(&config.bUpdateCache)->zero_tokens()->default_value(false), "Update game details cache")
             ("no-platform-detection", bpo::value<bool>(&bNoPlatformDetection)->zero_tokens()->default_value(false), "Don't try to detect supported platforms from game shelf.\nSkips the initial fast platform detection and detects the supported platforms from game details which is slower but more accurate.\nUseful in case platform identifier is missing for some games in the game shelf.\nUsing --platform with --list doesn't work with this option.")
-            ("download-file", bpo::value<std::string>(&config.sFileIdString)->default_value(""), "Download a single file using fileid\nFormat: \"gamename/fileid\"\nThis option ignores all subdir options. The file is downloaded to directory specified with --directory option.")
+            ("download-file", bpo::value<std::string>(&config.sFileIdString)->default_value(""), "Download files using fileid\n\nFormat:\n\"gamename/fileid\"\nor: \"gogdownloader://gamename/fileid\"\n\nMultiple files:\n\"gamename1/fileid1,gamename2/fileid2\"\nor: \"gogdownloader://gamename1/fileid1,gamename2/fileid2\"\n\nThis option ignores all subdir options. The files are downloaded to directory specified with --directory option.")
+            ("output-file,o", bpo::value<std::string>(&config.sOutputFilename)->default_value(""), "Set filename of file downloaded with --download-file.")
             ("wishlist", bpo::value<bool>(&config.bShowWishlist)->zero_tokens()->default_value(false), "Show wishlist")
+            ("login-api", bpo::value<bool>(&config.bLoginAPI)->zero_tokens()->default_value(false), "Login (API only)")
+            ("login-website", bpo::value<bool>(&config.bLoginHTTP)->zero_tokens()->default_value(false), "Login (website only)")
         ;
         // Commandline options (config file)
         options_cli_cfg.add_options()
@@ -159,16 +173,8 @@ int main(int argc, char *argv[])
             ("limit-rate", bpo::value<curl_off_t>(&config.iDownloadRate)->default_value(0), "Limit download rate to value in kB\n0 = unlimited")
             ("xml-directory", bpo::value<std::string>(&config.sXMLDirectory), "Set directory for GOG XML files")
             ("chunk-size", bpo::value<size_t>(&config.iChunkSize)->default_value(10), "Chunk size (in MB) when creating XML")
-            ("platform", bpo::value<unsigned int>(&config.iInstallerType)->default_value(GlobalConstants::PLATFORM_WINDOWS|GlobalConstants::PLATFORM_LINUX), platform_text.c_str())
-            ("language", bpo::value<unsigned int>(&config.iInstallerLanguage)->default_value(GlobalConstants::LANGUAGE_EN), language_text.c_str())
-            ("no-installers", bpo::value<bool>(&bNoInstallers)->zero_tokens()->default_value(false), "Don't download/list/repair installers")
-            ("no-extras", bpo::value<bool>(&bNoExtras)->zero_tokens()->default_value(false), "Don't download/list/repair extras")
-            ("no-patches", bpo::value<bool>(&bNoPatches)->zero_tokens()->default_value(false), "Don't download/list/repair patches")
-            ("no-language-packs", bpo::value<bool>(&bNoLanguagePacks)->zero_tokens()->default_value(false), "Don't download/list/repair language packs")
-            ("no-dlc", bpo::value<bool>(&bNoDLC)->zero_tokens()->default_value(false), "Don't download/list/repair DLCs")
-            ("no-deb", bpo::value<bool>(&bNoDeb)->zero_tokens()->default_value(false), "Don't download/list/repair deb packages")
-            ("no-targz", bpo::value<bool>(&bNoTarGz)->zero_tokens()->default_value(false), "Don't download/list/repair tarballs")
-            ("cover", bpo::value<bool>(&config.bCover)->zero_tokens()->default_value(false), "Download cover images")
+            ("platform", bpo::value<std::string>(&sInstallerPlatform)->default_value("w+l"), platform_text.c_str())
+            ("language", bpo::value<std::string>(&sInstallerLanguage)->default_value("en"), language_text.c_str())
             ("no-remote-xml", bpo::value<bool>(&bNoRemoteXML)->zero_tokens()->default_value(false), "Don't use remote XML for repair")
             ("no-unicode", bpo::value<bool>(&bNoUnicode)->zero_tokens()->default_value(false), "Don't use Unicode in the progress bar")
             ("no-color", bpo::value<bool>(&bNoColor)->zero_tokens()->default_value(false), "Don't use coloring in the progress bar")
@@ -188,10 +194,10 @@ int main(int argc, char *argv[])
             ("subdir-game", bpo::value<std::string>(&config.sGameSubdir)->default_value("%gamename%"), ("Set subdirectory for game" + subdir_help_text).c_str())
             ("use-cache", bpo::value<bool>(&config.bUseCache)->zero_tokens()->default_value(false), ("Use game details cache"))
             ("cache-valid", bpo::value<int>(&config.iCacheValid)->default_value(2880), ("Set how long cached game details are valid (in minutes)\nDefault: 2880 minutes (48 hours)"))
-            ("language-priority", bpo::value<std::string>(&config.sLanguagePriority)->default_value(""), ("Set priority of systems" + priority_help_text + ", like \"4,1\" for French first, then English if no French version").c_str())
-            ("platform-priority", bpo::value<std::string>(&config.sPlatformPriority)->default_value(""), ("Set priority of platforms" + priority_help_text + ", like \"4,1\" for Linux first, then Windows if no Linux version").c_str())
             ("save-serials", bpo::value<bool>(&config.bSaveSerials)->zero_tokens()->default_value(false), "Save serial numbers when downloading")
             ("ignore-dlc-count", bpo::value<std::string>(&config.sIgnoreDLCCountRegex)->implicit_value(".*"), "Set regular expression filter for games to ignore DLC count information\nIgnoring DLC count information helps in situations where the account page doesn't provide accurate information about DLCs")
+            ("include", bpo::value<std::string>(&sIncludeOptions)->default_value("all"), ("Select what to download/list/repair\n" + include_options_text).c_str())
+            ("exclude", bpo::value<std::string>(&sExcludeOptions)->default_value("covers"), ("Select what not to download/list/repair\n" + include_options_text).c_str())
         ;
         // Options read from config file
         options_cfg_only.add_options()
@@ -202,7 +208,9 @@ int main(int argc, char *argv[])
         options_cli_all.add(options_cli_no_cfg).add(options_cli_cfg);
         options_cfg_all.add(options_cfg_only).add(options_cli_cfg);
 
-        bpo::store(bpo::parse_command_line(argc, argv, options_cli_all), vm);
+        bpo::parsed_options parsed = bpo::parse_command_line(argc, argv, options_cli_all);
+        bpo::store(parsed, vm);
+        unrecognized_options_cli = bpo::collect_unrecognized(parsed.options, bpo::include_positional);
         bpo::notify(vm);
 
         if (vm.count("help"))
@@ -218,19 +226,6 @@ int main(int argc, char *argv[])
             return 0;
         }
 
-        if (xdgconfig)
-        {
-            config.sConfigDirectory = (std::string)xdgconfig + "/lgogdownloader";
-        }
-        else
-        {
-            config.sConfigDirectory = home + "/.config/lgogdownloader";
-        }
-
-        config.sCookiePath = config.sConfigDirectory + "/cookies.txt";
-        config.sConfigFilePath = config.sConfigDirectory + "/config.cfg";
-        config.sBlacklistFilePath = config.sConfigDirectory + "/blacklist.txt";
-
         // Create lgogdownloader directories
         boost::filesystem::path path = config.sXMLDirectory;
         if (!boost::filesystem::exists(path))
@@ -296,22 +291,9 @@ int main(int argc, char *argv[])
                     std::getline(ifs, line);
                     lines.push_back(std::move(line));
                 }
-                if (bNoDeb)
-                    lines.push_back("Rp .*\\.deb$");
-                if (bNoTarGz)
-                    lines.push_back("Rp .*\\.tar\\.gz$");
                 config.blacklist.initialize(lines);
             }
         }
-        else if (bNoDeb || bNoTarGz)
-        {
-            std::vector<std::string> lines;
-            if (bNoDeb)
-                lines.push_back("Rp .*\\.deb$");
-            if (bNoTarGz)
-                lines.push_back("Rp .*\\.tar\\.gz$");
-            config.blacklist.initialize(lines);
-        }
 
         if (vm.count("chunk-size"))
             config.iChunkSize <<= 20; // Convert chunk size from bytes to megabytes
@@ -333,25 +315,60 @@ int main(int argc, char *argv[])
         config.bColor = !bNoColor;
         config.bUnicode = !bNoUnicode;
         config.bDuplicateHandler = !bNoDuplicateHandler;
-        config.bInstallers = !bNoInstallers;
-        config.bExtras = !bNoExtras;
-        config.bPatches = !bNoPatches;
-        config.bLanguagePacks = !bNoLanguagePacks;
-        config.bDLC = !bNoDLC;
         config.bRemoteXML = !bNoRemoteXML;
         config.bSubDirectories = !bNoSubDirectories;
         config.bPlatformDetection = !bNoPlatformDetection;
 
-        // Override cover option
-        if (bNoCover)
-            config.bCover = false;
+        for (auto i = unrecognized_options_cli.begin(); i != unrecognized_options_cli.end(); ++i)
+            if (i->compare(0, GlobalConstants::PROTOCOL_PREFIX.length(), GlobalConstants::PROTOCOL_PREFIX) == 0)
+                config.sFileIdString = *i;
 
-	// Handle priority business
-	if (!config.sLanguagePriority.empty())
-	    handle_priority("languages", config.sLanguagePriority, config.vLanguagePriority, config.iInstallerLanguage);
-	if (!config.sPlatformPriority.empty())
-	    handle_priority("platforms", config.sPlatformPriority, config.vPlatformPriority, config.iInstallerType);
+        if (!config.sFileIdString.empty())
+        {
+            if (config.sFileIdString.compare(0, GlobalConstants::PROTOCOL_PREFIX.length(), GlobalConstants::PROTOCOL_PREFIX) == 0)
+            {
+                config.sFileIdString.replace(0, GlobalConstants::PROTOCOL_PREFIX.length(), "");
+            }
+            vFileIdStrings = Util::tokenize(config.sFileIdString, ",");
+        }
 
+        if (!config.sOutputFilename.empty() && vFileIdStrings.size() > 1)
+        {
+            std::cerr << "Cannot specify an output file name when downloading multiple files." << std::endl;
+            return 1;
+        }
+
+        if (bLogin)
+        {
+            config.bLoginAPI = true;
+            config.bLoginHTTP = true;
+        }
+
+        parseOptionString(sInstallerLanguage, config.vLanguagePriority, config.iInstallerLanguage, GlobalConstants::LANGUAGES);
+        parseOptionString(sInstallerPlatform, config.vPlatformPriority, config.iInstallerPlatform, GlobalConstants::PLATFORMS);
+
+        unsigned int include_value = 0;
+        unsigned int exclude_value = 0;
+        std::vector<std::string> vInclude = Util::tokenize(sIncludeOptions, ",");
+        std::vector<std::string> vExclude = Util::tokenize(sExcludeOptions, ",");
+        for (std::vector<std::string>::iterator it = vInclude.begin(); it != vInclude.end(); it++)
+        {
+            include_value |= Util::getOptionValue(*it, INCLUDE_OPTIONS);
+        }
+        for (std::vector<std::string>::iterator it = vExclude.begin(); it != vExclude.end(); it++)
+        {
+            exclude_value |= Util::getOptionValue(*it, INCLUDE_OPTIONS);
+        }
+        config.iInclude = include_value & ~exclude_value;
+
+        // Assign values
+        // TODO: Use config.iInclude in Downloader class directly and get rid of this value assignment
+        config.bCover = (config.iInclude & OPTION_COVERS);
+        config.bInstallers = (config.iInclude & OPTION_INSTALLERS);
+        config.bExtras = (config.iInclude & OPTION_EXTRAS);
+        config.bPatches = (config.iInclude & OPTION_PATCHES);
+        config.bLanguagePacks = (config.iInclude & OPTION_LANGPACKS);
+        config.bDLC = (config.iInclude & OPTION_DLCS);
     }
     catch (std::exception& e)
     {
@@ -364,13 +381,13 @@ int main(int argc, char *argv[])
         return 1;
     }
 
-    if (config.iInstallerType < GlobalConstants::PLATFORMS[0].platformId || config.iInstallerType > platform_sum)
+    if (config.iInstallerPlatform < GlobalConstants::PLATFORMS[0].id || config.iInstallerPlatform > platform_all)
     {
         std::cout << "Invalid value for --platform" << std::endl;
         return 1;
     }
 
-    if (config.iInstallerLanguage < GlobalConstants::LANGUAGES[0].languageId || config.iInstallerLanguage > language_sum)
+    if (config.iInstallerLanguage < GlobalConstants::LANGUAGES[0].id || config.iInstallerLanguage > language_all)
     {
         std::cout << "Invalid value for --language" << std::endl;
         return 1;
@@ -415,8 +432,10 @@ int main(int argc, char *argv[])
     int initResult = downloader.init();
 
     int iLoginResult = 0;
-    if (config.bLogin || initResult == 1)
+    if (config.bLoginAPI || config.bLoginHTTP || initResult == 1)
     {
+        if (!config.bLoginAPI && !config.bLoginHTTP)
+            downloader.config.bLoginAPI = true;
         iLoginResult = downloader.login();
         if (iLoginResult == 0)
             return 1;
@@ -483,7 +502,8 @@ int main(int argc, char *argv[])
             }
             ofs.close();
             Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
-            return 0;
+            if (config.bSaveConfig)
+                return 0;
         }
         else
         {
@@ -511,14 +531,19 @@ int main(int argc, char *argv[])
             return 1;
         }
     }
-    else if (config.bShowWishlist)
+    if (config.bShowWishlist)
         downloader.showWishlist();
     else if (config.bUpdateCache)
         downloader.updateCache();
     else if (config.bUpdateCheck) // Update check has priority over download and list
         downloader.updateCheck();
-    else if (!config.sFileIdString.empty())
-        downloader.downloadFileWithId(config.sFileIdString);
+    else if (!vFileIdStrings.empty())
+    {
+        for (std::vector<std::string>::iterator it = vFileIdStrings.begin(); it != vFileIdStrings.end(); it++)
+        {
+            downloader.downloadFileWithId(*it, config.sOutputFilename);
+        }
+    }
     else if (config.bRepair) // Repair file
         downloader.repair();
     else if (config.bDownload) // Download games
