@@ -97,14 +97,7 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
 
     if (xml_dir.empty())
     {
-        char *xdgcache = getenv("XDG_CACHE_HOME");
-        if (xdgcache)
-            xml_dir = (std::string)xdgcache + "/lgogdownloader/xml";
-        else
-        {
-            std::string home = (std::string)getenv("HOME");
-            xml_dir = home + "/.cache/lgogdownloader/xml";
-        }
+        xml_dir = Util::getCacheHome() + "/lgogdownloader/xml";
     }
 
     // Make sure directory exists
@@ -229,14 +222,7 @@ int Util::getGameSpecificConfig(std::string gamename, gameSpecificConfig* conf,
 
     if (directory.empty())
     {
-        char *xdghome = getenv("XDG_CONFIG_HOME");
-        if (xdghome)
-            directory = (std::string)xdghome + "/lgogdownloader";
-        else
-        {
-            std::string home = (std::string)getenv("HOME");
-            directory = home + "/.config/lgogdownloader";
-        }
+        directory = Util::getConfigHome() + "/lgogdownloader/gamespecific";
     }
 
     std::string filepath = directory + "/" + gamename + ".conf";
@@ -259,7 +245,7 @@ int Util::getGameSpecificConfig(std::string gamename, gameSpecificConfig* conf,
         }
         if (root.isMember("platform"))
         {
-            conf->iInstallerType = root["platform"].asUInt();
+            conf->iInstallerPlatform = root["platform"].asUInt();
             res++;
         }
         if (root.isMember("dlc"))
@@ -301,9 +287,9 @@ void Util::filepathReplaceReservedStrings(std::string& str, const std::string& g
     std::string platform;
     for (unsigned int i = 0; i < GlobalConstants::PLATFORMS.size(); ++i)
     {
-        if ((platformId & GlobalConstants::PLATFORMS[i].platformId) == GlobalConstants::PLATFORMS[i].platformId)
+        if ((platformId & GlobalConstants::PLATFORMS[i].id) == GlobalConstants::PLATFORMS[i].id)
         {
-            platform = boost::algorithm::to_lower_copy(GlobalConstants::PLATFORMS[i].platformString);
+            platform = boost::algorithm::to_lower_copy(GlobalConstants::PLATFORMS[i].str);
             break;
         }
     }
@@ -374,11 +360,10 @@ std::vector<std::string> Util::getDLCNamesFromJSON(const Json::Value &root)
     for (unsigned int i = 0; i < urls.size(); ++i)
     {
         std::string gamename;
-        std::string match_string = "gogdownloader://";
-        if (urls[i].find(match_string) == std::string::npos)
+        if (urls[i].find(GlobalConstants::PROTOCOL_PREFIX) == std::string::npos)
             continue;
 
-        gamename.assign(urls[i].begin()+urls[i].find(match_string)+match_string.length(), urls[i].begin()+urls[i].find_last_of("/"));
+        gamename.assign(urls[i].begin()+urls[i].find(GlobalConstants::PROTOCOL_PREFIX)+GlobalConstants::PROTOCOL_PREFIX.length(), urls[i].begin()+urls[i].find_last_of("/"));
         bool bDuplicate = false;
         for (unsigned int j = 0; j < dlcnames.size(); ++j)
         {
@@ -393,3 +378,96 @@ std::vector<std::string> Util::getDLCNamesFromJSON(const Json::Value &root)
     }
     return dlcnames;
 }
+
+std::string Util::getHomeDir()
+{
+    return (std::string)getenv("HOME");
+}
+
+std::string Util::getConfigHome()
+{
+    std::string configHome;
+    char *xdgconfig = getenv("XDG_CONFIG_HOME");
+    if (xdgconfig)
+        configHome = (std::string)xdgconfig;
+    else
+        configHome = Util::getHomeDir() + "/.config";
+    return configHome;
+}
+
+std::string Util::getCacheHome()
+{
+    std::string cacheHome;
+    char *xdgcache = getenv("XDG_CACHE_HOME");
+    if (xdgcache)
+        cacheHome = (std::string)xdgcache;
+    else
+        cacheHome = Util::getHomeDir() + "/.cache";
+    return cacheHome;
+}
+
+std::vector<std::string> Util::tokenize(const std::string& str, const std::string& separator)
+{
+    std::vector<std::string> tokens;
+    std::string token;
+    size_t idx = 0, found;
+    while ((found = str.find(separator, idx)) != std::string::npos)
+    {
+        token = str.substr(idx, found - idx);
+        if (!token.empty())
+            tokens.push_back(token);
+        idx = found + separator.length();
+    }
+    token = str.substr(idx);
+    if (!token.empty())
+        tokens.push_back(token);
+
+    return tokens;
+}
+
+unsigned int Util::getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options)
+{
+    unsigned int value = 0;
+    boost::regex expression("^[+-]?\\d+$", boost::regex::perl);
+    boost::match_results<std::string::const_iterator> what;
+    if (str == "all")
+    {
+        value = (1 << options.size()) - 1;
+    }
+    else if (boost::regex_search(str, what, expression))
+    {
+        value = std::stoi(str);
+    }
+    else
+    {
+        for (unsigned int i = 0; i < options.size(); ++i)
+        {
+            if (!options[i].regexp.empty())
+            {
+                boost::regex expr("^(" + options[i].regexp + ")$", boost::regex::perl | boost::regex::icase);
+                if (boost::regex_search(str, what, expr))
+                {
+                    value = options[i].id;
+                    break;
+                }
+            }
+            else if (str == options[i].code)
+            {
+                value = options[i].id;
+                break;
+            }
+        }
+    }
+    return value;
+}
+
+std::string Util::getOptionNameString(const unsigned int& value, const std::vector<GlobalConstants::optionsStruct>& options)
+{
+    std::string str;
+    for (unsigned int i = 0; i < options.size(); ++i)
+    {
+        if (value & options[i].id)
+            str += (str.empty() ? "" : ", ")+options[i].str;
+    }
+    return str;
+}
